import os
from ShynaDatabase import Shdatabase
from Shynatime import ShTime
from ShynaWeather import ShynaWeather


# Done : Added to 12 AM task, will help in updating weather
class UpdateWeather:
    s_data = Shdatabase.ShynaDatabase()
    s_time = ShTime.ClassTime()
    s_process = ShynaWeather.ShynaWeather()
    update_weather = False
    result = []
    lat = ''
    lon = ''

    def update_weather_sentence(self):
        try:
            self.s_data.default_database = os.environ.get('location_db')
            self.s_data.query = "SELECT new_latitude, new_longitude FROM shivam_device_location ORDER by count  " \
                                "DESC LIMIT 1;"
            self.result = self.s_data.select_from_table()
            for item in self.result:
                self.lat = item[0]
                self.lon = item[1]
            self.s_process.lon = self.lon
            self.s_process.lat = self.lat
            response = self.s_process.get_weather()
            speak_sentence = "I sense it is " + str(response['condition']) + " weather in " + str(
                response['name']) + ". it feels like "+ str(response['feelslike_c'])
            last_up_dt, last_up_time = self.s_time.get_date_and_time(text_string=response['last_updated'])
            self.s_data.default_database = os.environ.get('weather_db')
            self.s_data.query = "INSERT INTO weather_table (task_date, task_time, sunrise, sunset,weather_description,"\
                                "main_temp, main_feels_like, main_humidity, wind_gust, wind_speed, clouds, loc_name, " \
                                "speak_sentence, visibility, wind_direction, precipitation, moonrise, moonset," \
                                " last_update_date, last_update_time) VALUES('" + str(self.s_time.now_date) + "','" \
                                + str(self.s_time.now_time) + "','" \
                                + str(self.s_time.get_date_and_time(text_string=response['sunrise'])[1]) + "','" \
                                + str(self.s_time.get_date_and_time(text_string=response['sunset'])[1]) + "','" \
                                + str(response['condition']) + "','" + str(response['temp_c']) + "','" \
                                + str(response['feelslike_c']) + "','" + str(response['humidity']) + "','" \
                                + str(response['gust_kph']) + "','" + str(response['wind_kph']) + "','" \
                                + str(response['cloud']) + "','" + str(response['name']) + "','" + str(speak_sentence) \
                                + "','" + str(response['vis_km']) + "','" + str(response['wind_dir']) + "','" \
                                + str(response['precip_mm']) + "','" + str(response['moonrise']) + "','" \
                                + str(response['moonset']) + "','" + str(last_up_dt) + "','" \
                                + str(last_up_time) + "')"
            self.s_data.create_insert_update_or_delete()
            self.update_weather = True
        except Exception as e:
            self.update_weather = False
            print(e)
        finally:
            self.s_data.set_date_system(process_name="update_weather")
            return self.update_weather


if __name__ == "__main__":
    UpdateWeather().update_weather_sentence()



import requests
from ShynaDatabase import Shdatabase
from Shynatime import ShTime
import os


# TODO: we have database here, need to reconfigure.

class ShynaWeather:
    """
    Define either lon/lat or city_name. for shyna the lat and lon will be fetched from the database.
    get_weather_lon_lat: return weather details in dict as per lat/lon
    get_astronomy_lon_lat: return astro details in dict as per lat/lon
    get_weather_city: return weather details in dict as per city name
    get_astronomy_city : return astro details in dict as per city name
    get_weather: this will return the complete details. astro and weather.
    """

    weather_headers = {
        'x-rapidapi-host': "weatherapi-com.p.rapidapi.com",
        'x-rapidapi-key': "pG7DIQheytmshvuLgNTRSRs3yTogp1f0rDBjsnjIaJXtHxwvdG"
    }
    weather_dict = {}
    astro_dict = {}
    lat = None
    lon = None
    city_name = None
    s_data = Shdatabase.ShynaDatabase()
    s_time = ShTime.ClassTime()

    def get_weather_lon_lat(self):
        url = "https://weatherapi-com.p.rapidapi.com/current.json"
        w_query = str(self.lat) + "," + str(self.lon)
        # querystring = {"q": "28.698255,77.461441"}
        querystring = {"q": w_query}
        try:
            response = requests.request("GET", url=url, headers=self.weather_headers, params=querystring)
            response = eval(response.text)
            for _, val in response.items():
                for key, value in val.items():
                    if key == "condition":
                        self.weather_dict[key] = value['text']
                    else:
                        self.weather_dict[key] = value
        except Exception as e:
            self.weather_dict['error'] = e
            print(e)
        finally:
            return self.weather_dict

    def get_astronomy_lon_lat(self):
        url = "https://weatherapi-com.p.rapidapi.com/astronomy.json"
        w_query = str(self.lat) + "," + str(self.lon)
        querystring = {"q": w_query}
        try:
            response = requests.request("GET", url=url, headers=self.weather_headers, params=querystring)
            response = eval(response.text)
            for _, val in response.items():
                for key, value in val.items():
                    if key == 'astro':
                        for keys, values in value.items():
                            self.astro_dict[keys] = values
                    else:
                        pass
        except Exception as e:
            self.astro_dict['error'] = e
            print(e)
        finally:
            return self.astro_dict

    def get_weather_city(self):
        url = "https://weatherapi-com.p.rapidapi.com/current.json"
        querystring = {"q": self.city_name}
        try:
            response = requests.request("GET", url=url, headers=self.weather_headers, params=querystring)
            response = eval(response.text)
            for _, val in response.items():
                for key, value in val.items():
                    if key == "condition":
                        self.weather_dict[key] = value['text']
                    else:
                        self.weather_dict[key] = value
        except Exception as e:
            self.weather_dict['error'] = e
            print(e)
        finally:
            return self.weather_dict

    def get_astronomy_city(self):
        url = "https://weatherapi-com.p.rapidapi.com/astronomy.json"
        querystring = {"q": self.city_name}
        try:
            response = requests.request("GET", url=url, headers=self.weather_headers, params=querystring)
            response = eval(response.text)
            for _, val in response.items():
                for key, value in val.items():
                    if key == 'astro':
                        for keys, values in value.items():
                            self.astro_dict[keys] = values
                    else:
                        pass
        except Exception as e:
            self.astro_dict['error'] = e
            print(e)
        finally:
            return self.astro_dict

    def get_weather(self):
        try:
            if self.lat is None and self.lon is None and self.city_name is None:
                self.weather_dict['Error'] = "Please define either latitude or Longitude OR city name"
            elif self.lat is None and self.lon is None:
                self.weather_dict = self.get_weather_city()
                self.astro_dict = self.get_astronomy_city()
                self.weather_dict.update(self.astro_dict)
            else:
                self.weather_dict = self.get_weather_lon_lat()
                self.astro_dict = self.get_astronomy_lon_lat()
                self.weather_dict.update(self.astro_dict)
        except Exception as e:
            self.weather_dict['error'] = e
            print(e)
        finally:
            return self.weather_dict

    def get_weather_sentence(self):
        weather_sentence = False
        try:
            self.s_data.default_database = os.environ.get('weather_db')
            self.s_data.query = "SELECT speak_sentence FROM weather_table where task_date = '" \
                                + str(self.s_time.now_date) + "'"
            result = self.s_data.select_from_table()
            for item in result:
                weather_sentence = item[0]
        except Exception as e:
            weather_sentence = False
            print(e)
        finally:
            return weather_sentence

